"""almasru with ONB defaults."""

import re

from catalogue.sru import almasru


class OnbRecordRetriever(almasru.RecordRetriever):
    pid_re = re.compile(r'\d{7}')

    def __init__(self,
                 subdomain: str = 'obv-at-oenb',
                 inst_code: str = '43ACC_ONB',
                 xml_format: str = 'marcxml'):
        super().__init__(subdomain, inst_code, xml_format)

    # Create alias for querying AC-numbers
    def by_ac_num(self, ac_num: str):
        return self.by_marc_009(ac_num)

    def get_pids_for_ac(self, ac_num: str) -> list:
        """
        Extract all PIDs from XML based on MARC 856 4 2.
        PIDs are identifiers migrated from a legacy system.

        :param ac_num: ID used in Austrian Library Network
        :return: List of identifiers.
        """

        namespaces = {
            'srw': 'http://www.loc.gov/zing/srw/',
            'marc': 'http://www.loc.gov/MARC21/slim'
        }

        marc_xml = self.by_ac_num(ac_num)
        datafields = marc_xml.findall("marc:datafield", namespaces)

        pids = []

        for datafield in datafields:
            if datafield.attrib == {'tag': '856', 'ind1': '4', 'ind2': '2'}:
                marc_856_u = datafield.find("marc:subfield[@code='u']", namespaces)
                marc_856_url = marc_856_u.text
                marc_856_x = datafield.find("marc:subfield[@code='x']", namespaces)
                marc_856_note = marc_856_x.text
                if 'ONB-DTL' in marc_856_note:
                    pids.append(self.pid_re.findall(marc_856_url)[0])
                marc_856_url = None

        return pids
